@@ -1,16 +1,13 @@
-import MeCab
+from natto import MeCab
 from .node import Node
-import os
+
 
 class Parser:
     def parse(self, text):
-        m = MeCab.Tagger()
-        m.parse("")
-        n = m.parseToNode(text)
+        m = MeCab()
         results = []
-        while n:
+        for n in m.parse(text, as_nodes=True):
             tmp = Node(n.surface, n.feature, n.stat)
             if tmp.analyzable():
                 results.append(tmp)
-            n = n.next 
         return results
